@@ -7,14 +7,20 @@ from .senet import *
 from .xception import *
 from .nasnet import *
 from .pnasnet import *
-from .gen_efficientnet import *
+from .selecsls import *
+from .efficientnet import *
+from .mobilenetv3 import *
 from .inception_v3 import *
 from .gluon_resnet import *
 from .gluon_xception import *
 from .res2net import *
 from .dla import *
+from .hrnet import *
+from .sknet import *
+from .tresnet import *
 
 from .registry import *
 from .factory import create_model
 from .helpers import load_checkpoint, resume_checkpoint
-from .test_time_pool import TestTimePoolHead, apply_test_time_pool
+from .layers import TestTimePoolHead, apply_test_time_pool
+from .layers import convert_splitbn_model
